@@ -11,10 +11,9 @@ from typing import Any, Callable, Dict, List, Optional, Union
 if sys.platform == "win32":  # pragma: no cover
     from subprocess import list2cmdline
 else:
-    import pipes
 
     def list2cmdline(cmd_list):
-        return " ".join(map(pipes.quote, cmd_list))
+        return " ".join(map(shlex.quote, cmd_list))
 
 
 _logger = None
@@ -42,8 +41,6 @@ def npm_builder(
     editable_build_cmd: Optional[str] = None,
 ) -> None:
     """Build function for managing an npm installation.
-    Note: The function is a no-op if the `--skip-npm` cli flag is used
-        or HATCH_JUPYTER_BUILDER_SKIP_NPM env is set.
 
     Parameters
     ----------
@@ -64,11 +61,15 @@ def npm_builder(
         The npm command to build assets to the build_dir when building in editable mode.
     npm: str or list, optional.
         The npm executable name, or a tuple of ['node', executable].
+
+    Notes
+    -----
+    The function is a no-op if the `--skip-npm` cli flag is used
+        or HATCH_JUPYTER_BUILDER_SKIP_NPM env is set.
     """
 
     # Check if we are building a wheel from an sdist.
     abs_path = Path(path).resolve()
-    here = Path(os.getcwd()).resolve()
     log = _get_log()
 
     if "--skip-npm" in sys.argv or os.environ.get("HATCH_JUPYTER_BUILDER_SKIP_NPM") == "1":
@@ -79,10 +80,6 @@ def npm_builder(
     else:
         skip_npm = False
 
-    is_git_checkout = (here / ".git").exists()
-    if target_name == "wheel" and not is_git_checkout and not force:
-        skip_npm = True
-
     if skip_npm:
         log.info("Skipping npm-installation")
         return
@@ -117,6 +114,8 @@ def npm_builder(
         run(npm_cmd + ["install"], cwd=str(abs_path))
         if build_cmd:
             run(npm_cmd + ["run", build_cmd], cwd=str(abs_path))
+    else:
+        log.info("No build required")
 
 
 def is_stale(target: Union[str, Path], source: Union[str, Path]) -> bool:
@@ -232,6 +231,14 @@ def ensure_targets(ensured_targets: List[str]) -> None:
     for target in ensured_targets:
         if not Path(target).exists():
             raise ValueError(f'Ensured target "{target}" does not exist')
+    _get_log().info("Ensured target(s) exist!")
+
+
+def should_skip(skip_if_exists):
+    """Detect whether all the paths in skip_if_exists exist"""
+    if not isinstance(skip_if_exists, list) or not len(skip_if_exists):
+        return False
+    return all(os.path.exists(p) for p in skip_if_exists)
 
 
 def install_pre_commit_hook():
@@ -240,8 +247,13 @@ INSTALL_PYTHON={sys.executable}
 ARGS=(hook-impl --config=.pre-commit-config.yaml --hook-type=pre-commit)
 HERE="$(cd "$(dirname "$0")" && pwd)"
 ARGS+=(--hook-dir "$HERE" -- "$@")
-exec "$INSTALL_PYTHON" -mpre_commit "${{ARGS[@]}}"
+exec "$INSTALL_PYTHON" -m pre_commit "${{ARGS[@]}}"
 """
+    if not os.path.exists(".git"):
+        log = _get_log()
+        log.warning("Refusing to install pre-commit hook since this is not a git repository")
+        return
+
     path = ".git/hooks/pre-commit"
     with open(path, "w") as fid:
         fid.write(data)
